@@ -1,10 +1,9 @@
 package App::PrereqGrapher;
-{
-  $App::PrereqGrapher::VERSION = '0.11';
-}
+$App::PrereqGrapher::VERSION = '0.12';
 #
 # ABSTRACT: generate dependency graph using Perl::PrereqScanner
 #
+
 use 5.006;
 use strict;
 use warnings;
@@ -74,6 +73,7 @@ sub parse_options
     my %format;
 
     GetOptions(
+        'h|help'              => \$options{'help'},
         'd|depth=i'           => \$options{'depth'},
         't|timeout=i'         => \$options{'timeout'},
         'o|output-file=s'     => \$options{'output_file'},
@@ -86,6 +86,7 @@ sub parse_options
         'vcg'                 => \$format{'vcg'},
         'html'                => \$format{'html'},
     ) || croak "Can't get options.";
+    usage() if $options{'help'};
 
     foreach my $format (keys %formats) {
         delete $format{$format} unless $format{$format};
@@ -178,6 +179,13 @@ sub is_core
     return $version <= $final_release;
 }
 
+sub usage
+{
+    require Pod::Usage;
+    Pod::Usage::pod2usage();
+    exit;
+}
+
 1;
 
 =head1 NAME
@@ -368,7 +376,7 @@ to get dependency information.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/App-PrereqGrapher>
+L<https://github.com/neilb/App-PrereqGrapher>
 
 =head1 AUTHOR
 
